/*==============================================
		Graphs LiTS to prod and inequalities
===============================================*/


use flows_lits, clear

replace hire =. if year >2000
replace sep =. if year >2000

merge 1:1 c_code year using gdp 
drop _merge

merge 1:1 c_code year using gini_vshort 
drop _merge


drop if c_code=="TKM"| c_code =="YUG"
drop if c_code =="BiH"|c_code=="SRB"| c_code == "MNE"
egen aux = min(c_n), by(c_code)
replace c_n = aux if c_n==.


gen same_cy = 0
replace same_cy = 1 if c_code=="BGR" & year>1989 & year<1998
replace same_cy = 1 if c_code=="CZE" & year>1993 & year<1999
replace same_cy = 1 if c_code=="EST" & year>1989 & year<2000
replace same_cy = 1 if c_code=="HUN" & year>1989 & year<1994
replace same_cy = 1 if c_code=="POL" & (year==1990 | (year>1993 & year<2000))
replace same_cy = 1 if c_code=="ROM" & ((year>1989 & year<1994) | (year>1994 & year<1998))
replace same_cy = 1 if c_code=="RUS" & year>1989 & year<1999
replace same_cy = 1 if c_code=="SVN" & year>1990 & year<2000
replace same_cy = 1 if c_code=="UKR" & year>1991 & year<2000

egen same_c  =max(same_cy), by(c_code)

gen all =1


drop if c_n ==.
replace hire = . if year>2000
replace sep = . if year>2000
xtset c_n year

local m=0
foreach var in same_cy same_c all{
foreach lhs in prod gini chain{

matrix `lhs'_`m' = J(11,7,-99)

local v = 0
foreach rhs in hire sep{
local ++v
forvalues i = 1/11{
local j = `i' -1


reg f`j'.`lhs' `rhs' i.c_n if year>=1989 & `var'==1, level(90)
matrix b = r(table)

matrix `lhs'_`m'[`i',1] = `j'
matrix `lhs'_`m'[`i',`v'*3-1]   = b[1,1]
matrix `lhs'_`m'[`i',`v'*3] 	= b[5,1]
matrix `lhs'_`m'[`i',`v'*3+1] 	= b[6,1]


}
}
}
local ++m
}
*

clear



*Figure 3 LiTS
svmat prod_1, n(c)
local c =0
foreach n in  T hire lowhire uphire sep lowsep upsep {
local ++c
ren c`c' `n'
}

twoway (line hire T, sort lcolor(gs2)) (line lowhire T, sort lcolor(gs6) lwidth(thin) lpattern(dash)) ///
	   (line uphire T, sort lcolor(gs6) lwidth(thin) lpattern(dash)), ///
	   xtitle("Time") ytitle("Coefficient") title("Hirings", color(black)) legend(off) ///
	   graphregion(fcolor(gs15) lcolor(gs15)) ///
	   yline(0, lcolor(black)) name(hire_prod_cy, replace) ///

	   
twoway (line sep T, sort lcolor(gs2)) (line lowsep T, sort lcolor(gs6) lwidth(thin) lpattern(dash)) ///
	   (line upsep T, sort lcolor(gs6) lwidth(thin) lpattern(dash)), ///
	   xtitle("Time") ytitle("Coefficient") title("Separations", color(black)) legend(off) ///
	   graphregion(fcolor(gs15) lcolor(gs15)) ///
	   yline(0, lcolor(black)) name(sep_prod_cy, replace) ///

clear

*Figure 4 LiTS

svmat gini_1, n(c)
local c =0
foreach n in  T hire lowhire uphire sep lowsep upsep {
local ++c
ren c`c' `n'
}

twoway (line hire T, sort lcolor(gs2)) (line lowhire T, sort lcolor(gs6) lwidth(thin) lpattern(dash)) ///
	   (line uphire T, sort lcolor(gs6) lwidth(thin) lpattern(dash)), ///
	   xtitle("Time") ytitle("Coefficient") title("Hirings", color(black)) legend(off) ///
	   graphregion(fcolor(gs15) lcolor(gs15)) ///
	   yline(0, lcolor(black)) name(hire_gini_cy, replace)  

	   
twoway (line sep T, sort lcolor(gs2)) (line lowsep T, sort lcolor(gs6) lwidth(thin) lpattern(dash)) ///
	   (line upsep T, sort lcolor(gs6) lwidth(thin) lpattern(dash)), ///
	   xtitle("Time") ytitle("Coefficient") title("Separations",color(black)) ///
	   legend(off) ///
	   graphregion(fcolor(gs15) lcolor(gs15)) ///
	   yline(0, lcolor(black)) name(sep_gini_cy, replace) 

clear


*Figure 5 LiTS

svmat prod_2, n(c)
local c =0
foreach n in  T hire lowhire uphire sep lowsep upsep {
local ++c
ren c`c' `n'
}

twoway (line hire T, sort lcolor(gs2)) (line lowhire T, sort lcolor(gs6) lwidth(thin) lpattern(dash)) ///
	   (line uphire T, sort lcolor(gs6) lwidth(thin) lpattern(dash)), ///
	   xtitle("Time") ytitle("Coefficient") title("Hirings", color(black)) legend(off) ///
	   graphregion(fcolor(gs15) lcolor(gs15)) ///
	   yline(0, lcolor(black)) name(hire_prod_all, replace) ///

	   
twoway (line sep T, sort lcolor(gs2)) (line lowsep T, sort lcolor(gs6) lwidth(thin) lpattern(dash)) ///
	   (line upsep T, sort lcolor(gs6) lwidth(thin) lpattern(dash)), ///
	   xtitle("Time") ytitle("Coefficient") title("Separations", color(black)) legend(off) ///
	   graphregion(fcolor(gs15) lcolor(gs15)) ///
	   yline(0, lcolor(black)) name(sep_prod_all, replace) ///

clear 
	   
svmat gini_2, n(c)
local c =0
foreach n in  T hire lowhire uphire sep lowsep upsep {
local ++c
ren c`c' `n'
}

twoway (line hire T, sort lcolor(gs2)) (line lowhire T, sort lcolor(gs6) lwidth(thin) lpattern(dash)) ///
	   (line uphire T, sort lcolor(gs6) lwidth(thin) lpattern(dash)), ///
	   xtitle("Time") ytitle("Coefficient") title("Hirings", color(black)) legend(off) ///
	   graphregion(fcolor(gs15) lcolor(gs15)) ///
	   yline(0, lcolor(black)) name(hire_gini_all, replace)  

	   
twoway (line sep T, sort lcolor(gs2)) (line lowsep T, sort lcolor(gs6) lwidth(thin) lpattern(dash)) ///
	   (line upsep T, sort lcolor(gs6) lwidth(thin) lpattern(dash)), ///
	   xtitle("Time") ytitle("Coefficient") title("Separations",color(black)) ///
	   legend(off) ///
	   graphregion(fcolor(gs15) lcolor(gs15)) ///
	   yline(0, lcolor(black)) name(sep_gini_all, replace) 
	   
